Sqe

Struct Sqe 

pub struct Sqe { /* private fields */ }

Implementations

Source

impl Sqe

pub const SUPPORTS_RECV_DISCARD: bool = true

pub fn entry(&self) -> &Entry

pub fn create_meta(&self) -> Option<Create>

pub fn from_entry(entry: Entry) -> Self

pub fn send(fd: &Fd<'_>, buf: &[u8], op: Token) -> Self

pub fn send_at(slot: FdSlot, buf: &[u8], op: Token) -> Self

pub unsafe fn write_fd(fd: RawFd, buf: &[u8], offset: u64, op: Token) -> Self

Safety

fd must stay open and buf stable and unchanged until completion.

pub fn openat( dir: RawFd, path: *const c_char, flags: i32, mode: u32, op: Token, ) -> Self

pub unsafe fn openat_fixed( dir: RawFd, path: *const c_char, flags: i32, mode: u32, slot: FdSlot, op: Token, ) -> Result<Self>

Safety

dir and a NUL-terminated path must stay valid, and slot reserved, until completion.

pub unsafe fn read(fd: RawFd, buf: &mut [u8], offset: u64, op: Token) -> Self

Safety

fd must stay open and buf stable and unaliased until completion.

pub unsafe fn read_uninit( fd: RawFd, buf: &mut [MaybeUninit<u8>], offset: u64, op: Token, ) -> Self

Safety

fd must stay open and buf stable and unaliased until completion.

pub fn read_fixed_file_uninit( slot: FdSlot, buf: &mut [MaybeUninit<u8>], offset: u64, op: Token, ) -> Self

pub fn stat_path(path: *const c_char, stat: *mut statx, op: Token) -> Self

pub fn stat_fd(fd: RawFd, stat: *mut statx, op: Token) -> Self

pub unsafe fn splice_raw( fd_in: RawFd, off_in: i64, fd_out: RawFd, off_out: i64, len: u32, flags: u32, op: Token, ) -> Self

Safety

Both descriptors must stay open until completion.

pub fn splice_to_pipe( fd_in: RawFd, off_in: i64, pipe_write_fd: RawFd, len: u32, op: Token, ) -> Self

pub unsafe fn recv_multi(fd: &Fd<'_>, buf_group: u16, op: Token) -> Self

Safety

fd must belong to the receiving driver and stay live until completion.

pub unsafe fn recv_discard(fd: &Fd<'_>, remaining: u64, op: Token) -> Self

Safety

fd must belong to the receiving driver and stay live until completion.

pub fn accept_oneshot( listener: &Fd<'_>, addr_ptr: *mut sockaddr, addrlen_ptr: *mut socklen_t, op: Token, ) -> Self

pub fn recv_msg_multi( fd: &Fd<'_>, msghdr: &msghdr, buf_group: u16, op: Token, ) -> Self

pub fn send_msg(fd: &Fd<'_>, msg: &msghdr, op: Token) -> Self

pub fn close_at(slot: FdSlot) -> Self

pub fn quickack(fd: &Fd<'_>) -> Self

pub fn shutdown(fd: &Fd<'_>, how: i32) -> Self

pub fn shutdown_linked_at(slot: FdSlot, how: i32) -> Self

pub fn poll_shutdown(fd: RawFd) -> Self

pub fn cancel(target: Token, op_kind: u8) -> Self

pub fn interval(timer: &'static Timespec, op: Token) -> Self

Arms a kernel-owned recurring timer.

The timer specification is referenced by the multishot operation and must therefore remain live until the driver is torn down or the timer is cancelled.

pub fn cancel_create(slot: FdSlot) -> Self

pub fn socket( domain: i32, socket_type: i32, protocol: i32, fd: &Fd<'_>, op: Token, ) -> Result<Self>

pub fn socket_at( domain: i32, socket_type: i32, protocol: i32, slot: FdSlot, op: Token, ) -> Result<Self>

pub fn bind_at( slot: FdSlot, addr_ptr: *const sockaddr, addr_len: u32, op: Token, ) -> Self

pub fn listen_at(slot: FdSlot, backlog: i32, op: Token) -> Self

pub fn connect( fd: &Fd<'_>, addr_ptr: *const sockaddr, addr_len: u32, op: Token, ) -> Self